time_in_force_to_binance_spot

Function time_in_force_to_binance_spot 

pub fn time_in_force_to_binance_spot(
    tif: TimeInForce,
    use_gtd: bool,
) -> Result<BinanceTimeInForce>
Converts a Nautilus time in force to Binance Spot time in force.

Binance Spot only supports GTC, IOC, and FOK. When native GTD is disabled, GTD maps to GTC so a Nautilus strategy can manage expiry locally.

Errors

Returns an error if the time in force is not supported on Binance Spot.